@@ -118,7 +118,7 @@ def get_value(data, name, field, allow_many_nested=False):
     """Get a value from a dictionary. Handles ``MultiDict`` types when
     ``multiple=True``. If the value is not found, return `missing`.
 
-    :param object data: Mapping (e.g. :type:`dict`) or list-like instance to
+    :param object data: Mapping (e.g. `dict`) or list-like instance to
         pull the value from.
     :param str name: Name of the key.
     :param bool multiple: Whether to handle multiple values.
@@ -209,7 +209,7 @@ class Parser(object):
         given = set(locations)
         invalid_locations = given - valid_locations
         if len(invalid_locations):
-            msg = "Invalid locations arguments: {0}".format(list(invalid_locations))
+            msg = 'Invalid locations arguments: {0}'.format(list(invalid_locations))
             raise ValueError(msg)
         return locations
 
@@ -258,7 +258,7 @@ class Parser(object):
     def _parse_request(self, schema, req, locations):
         """Return a parsed arguments dictionary for the current request."""
         if schema.many:
-            assert 'json' in locations, "schema.many=True is only supported for JSON location"
+            assert 'json' in locations, 'schema.many=True is only supported for JSON location'
             # The ad hoc Nested field is more like a workaround or a helper, and it servers its
             # purpose fine. However, if somebody has a desire to re-design the support of
             # bulk-type arguments, go ahead.
@@ -289,7 +289,7 @@ class Parser(object):
         else:
             schema = argmap2schema(argmap)()
         if not schema.strict:
-            warnings.warn("It is highly recommended that you set strict=True on your schema "
+            warnings.warn('It is highly recommended that you set strict=True on your schema '
                 "so that the parser's error handler will be invoked when expected.", UserWarning)
         return schema.load(data)
 
@@ -326,6 +326,8 @@ class Parser(object):
         """
         if isinstance(argmap, ma.Schema):
             schema = argmap
+        elif isinstance(argmap, type) and issubclass(argmap, ma.Schema):
+            schema = argmap()
         elif callable(argmap):
             schema = argmap(req)
         else:
